Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-pages.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGrzegorz Bizon <grzesiek.bizon@gmail.com>2019-11-13 15:08:54 +0300
committerGrzegorz Bizon <grzesiek.bizon@gmail.com>2019-11-13 15:08:54 +0300
commit66473aec0d138a013963936ae293f1484630c0de (patch)
treedeea49b010fc1f02a2e336915b74378aa9ca707b /internal/source/gitlab/cache/entry.go
parent9452eadb1915363a08fb5e9dc0367af6107dfb08 (diff)
Rename entry function responsible for canceling context
Diffstat (limited to 'internal/source/gitlab/cache/entry.go')
-rw-r--r--internal/source/gitlab/cache/entry.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/internal/source/gitlab/cache/entry.go b/internal/source/gitlab/cache/entry.go
index 9a259ab7..55380a7b 100644
--- a/internal/source/gitlab/cache/entry.go
+++ b/internal/source/gitlab/cache/entry.go
@@ -94,9 +94,9 @@ func (e *Entry) Refresh(ctx context.Context, client Resolver, store Store) {
})
}
// CancelContexts cancels all cancelable contexts. Typically used when the
// entry is evicted from cache.
-func (e *Entry) CancelContexts() {
+func (e *Entry) CancelRetrieval() {
e.cancel()
}
@@ -94,9 +94,9 @@ func (e *Entry) Refresh(ctx context.Context, client Resolver, store Store) {
})
}
-// CancelContexts cancels all cancelable contexts. Typically used when the
+// CancelRetrieval cancels all cancelable contexts. Typically used when the
// entry is evicted from cache.